#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const os_1 = require("os");
const path_1 = require("path");
const staticfs_1 = require("./staticfs");
const patchRequire = require("./fs-monkey/index.js").patchRequire;
/**
 * helper functions
 */
function writePackagePath(packagePath, packageFilePath) {
    if (!fs.statSync(packageFilePath).isFile()) {
        throw new Error("Installation failed.");
    }
    console.log(`Recording package path for platform-specific runtime: ${packagePath}`);
    fs.writeFileSync(path_1.join(__dirname, "package-path.json"), JSON.stringify(packagePath));
}
function install(targetFolder, packageName, packagePath, packageFilePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const mainPath = `yarn/${require("yarn/package.json").bin.yarn}`;
        yield new Promise(res => require("mkdirp")(targetFolder, () => res()));
        process.chdir(targetFolder);
        process.argv = [process.argv[0], mainPath, 'add', packageName, "--force"];
        // setup our stuff for when it's done.
        process.on("exit", () => {
            writePackagePath(packagePath, packageFilePath);
        });
        // run yarn!
        require(mainPath);
    });
}
const fileExists = (path) => new Promise((r, j) => fs.stat(path, err => err ? r(false) : r(true)));
function detectArchitecture() {
    switch (os_1.platform()) {
        case 'darwin':
            return 'osx';
        case 'win32':
            switch (os_1.arch()) {
                case 'x64':
                    return 'win';
                case 'x86':
                    return 'win-x86';
            }
            break;
        case 'linux':
            return `linux`;
    }
    throw new Error(`Unsupported Platform: ${os_1.platform()}`);
}
/**
 * app
 */
const dotnetVersion = "2.0.0";
const pathOption = process.env.DOTNET_SHARED_HOME || path_1.normalize(`${os_1.homedir()}/.net/${dotnetVersion}`);
const archOption = process.env.DOTNET_SHARED_ARCH || detectArchitecture();
const packageName = `dotnet-${dotnetVersion}-${archOption}`;
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        // load node_modules from our squish'd fs file.
        patchRequire(yield staticfs_1.staticfs(`${__dirname}/static.fs`), true);
        const force = process.argv.indexOf("--force") !== -1;
        // derive paths
        const packagePath = path_1.join(pathOption, `node_modules/${packageName}/`);
        const packageFilePath = packagePath + "package.json";
        try {
            // force? => remove folder first
            if (force) {
                const rimraf = require('rimraf');
                yield new Promise((res, rej) => require(`rimraf`)(packagePath, (err) => err ? rej(err) : res()));
            }
            // install
            if (!(yield fileExists(packageFilePath))) {
                yield install(pathOption, packageName, packagePath, packageFilePath);
            }
            else {
                writePackagePath(packagePath, packageFilePath);
            }
        }
        catch (e) {
            console.error(e);
            process.exit(1);
        }
    });
}
main();
//# sourceMappingURL=app.js.map